pub enum CompareStepError {
Plan(PlanError),
Execute(ExecuteError),
}Expand description
A planning or generation failure while comparing derived output.
Variants
Plan(PlanError)
The workspace could not produce a generation plan.
Execute(ExecuteError)
The generation inputs or generator could not produce an in-memory tree.