pub fn run_command(
root: &Path,
spec: &CommandSpec,
) -> Result<CapturedOutput, SpawnError>Expand description
Runs spec at root through the host process API.
pub fn run_command(
root: &Path,
spec: &CommandSpec,
) -> Result<CapturedOutput, SpawnError>Runs spec at root through the host process API.